@@ -88,8 +88,8 @@ struct CtRecentDocRestore
 };
 
 typedef std::unordered_map<std::string, CtRecentDocRestore> CtRecentDocsRestore;
-class CtTableCell;
-typedef std::vector<CtTableCell*>   CtTableRow;
+class CtTextCell;
+typedef std::vector<CtTextCell*>    CtTableRow;
 typedef std::vector<CtTableRow>     CtTableMatrix;
 typedef std::vector<int>            CtTableColWidths;
 
@@ -168,6 +168,7 @@ struct CtStorageNodeState
 
 struct CtStorageSyncPending
 {
+    bool                                           fix_db_tables{true};
     bool                                           bookmarks_to_write{false};
     std::unordered_map<gint64, CtStorageNodeState> nodes_to_write_dict;
     std::set<gint64>                               nodes_to_rm_set;
